cmd

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 22, 2023 License: GPL-3.0 Imports: 15 Imported by: 0

Documentation

Overview

Copyright © 2023 Thomas von Dein

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() error

func GetApicontextsFromEnv

func GetApicontextsFromEnv(conf *cfg.Config)
Get a list of Api Contexts from ENV. Useful for use with k8s secrets.

Multiple env vars are supported in this format:

EPHEMERUPD_CONTEXT_$(NAME)="<context>:<key>"

eg:

EPHEMERUPD_CONTEXT_SUPPORT="support:tymag-fycyh-gymof-dysuf-doseb-puxyx"
                   ^^^^^^^- doesn't matter.

Modifies cfg.Config directly

Types

This section is empty.

Jump to